==> hs-monads-tf-0.1.0.0p3.tgz: lib/ghc/monads-tf-0.1.0.0/register.sh <==
#!/bin/sh
echo 'name: monads-tf
version: 0.1.0.0
id: monads-tf-0.1.0.0-03297f097ce5653fecfc41b260b62908

license: BSD3
copyright:
maintainer: Ross Paterson <ross@soi.city.ac.uk>
stability:
homepage:
package-url:
synopsis: Monad classes, using type families
description: Monad classes using type families, with instances for various
             monad transformers, inspired by the paper /Functional Programming
             with Overloading and Higher-Order Polymorphism/, by Mark P
             Jones, in /Advanced School of Functional Programming/, 1995
             (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
             .
             This package is almost a compatible replacement for the @mtl-tf@ package.
category: Control
author: Andy Gill
pkgpath: devel/hs-monads-tf
exposed: True
exposed-modules: Control.Monad.Cont Control.Monad.Cont.Class
                 Control.Monad.Error Control.Monad.Error.Class
                 Control.Monad.Identity Control.Monad.List Control.Monad.RWS
                 Control.Monad.RWS.Class Control.Monad.RWS.Lazy
                 Control.Monad.RWS.Strict Control.Monad.Reader
                 Control.Monad.Reader.Class Control.Monad.State
                 Control.Monad.State.Class Control.Monad.State.Lazy
                 Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
                 Control.Monad.Writer.Class Control.Monad.Writer.Lazy
                 Control.Monad.Writer.Strict
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/monads-tf-0.1.0.0
library-dirs: /usr/local/lib/ghc/monads-tf-0.1.0.0
hs-libraries: HSmonads-tf-0.1.0.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-monads-tf-0.1.0.0/html/monads-tf.haddock
haddock-html: /usr/local/share/doc/hs-monads-tf-0.1.0.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-monads-tf-0.1.0.1p1.tgz: lib/ghc/monads-tf-0.1.0.1/register.sh <==
#!/bin/sh
export PATH='/usr/obj/hs-monads-tf-0.1.0.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: monads-tf
version: 0.1.0.1
id: monads-tf-0.1.0.1-c436c493fa2376bc4e0dd5f92698879b

license: BSD3
copyright:
maintainer: Ross Paterson <ross@soi.city.ac.uk>
stability:
homepage:
package-url:
synopsis: Monad classes, using type families
description: Monad classes using type families, with instances for various
             monad transformers, inspired by the paper /Functional Programming
             with Overloading and Higher-Order Polymorphism/, by Mark P
             Jones, in /Advanced School of Functional Programming/, 1995
             (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
             .
             This package is almost a compatible replacement for the @mtl-tf@ package.
category: Control
author: Andy Gill
pkgpath: devel/hs-monads-tf
exposed: True
exposed-modules: Control.Monad.Cont Control.Monad.Cont.Class
                 Control.Monad.Error Control.Monad.Error.Class
                 Control.Monad.Identity Control.Monad.List Control.Monad.RWS
                 Control.Monad.RWS.Class Control.Monad.RWS.Lazy
                 Control.Monad.RWS.Strict Control.Monad.Reader
                 Control.Monad.Reader.Class Control.Monad.State
                 Control.Monad.State.Class Control.Monad.State.Lazy
                 Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
                 Control.Monad.Writer.Class Control.Monad.Writer.Lazy
                 Control.Monad.Writer.Strict
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/monads-tf-0.1.0.1
library-dirs: /usr/local/lib/ghc/monads-tf-0.1.0.1
hs-libraries: HSmonads-tf-0.1.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         transformers-0.3.0.0-6458c21515cab7c1cf21e53141557a1c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-monads-tf-0.1.0.1/html/monads-tf.haddock
haddock-html: /usr/local/share/doc/hs-monads-tf-0.1.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
